# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import httpx
import pytest
from respx import MockRouter

from casedev import Casedev, AsyncCasedev
from casedev._response import (
    BinaryAPIResponse,
    AsyncBinaryAPIResponse,
    StreamedBinaryAPIResponse,
    AsyncStreamedBinaryAPIResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestV1:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_method_create_document(self, client: Casedev, respx_mock: MockRouter) -> None:
        respx_mock.post("/format/v1/document").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        v1 = client.format.v1.create_document(
            content="content",
            output_format="pdf",
        )
        assert v1.is_closed
        assert v1.json() == {"foo": "bar"}
        assert cast(Any, v1.is_closed) is True
        assert isinstance(v1, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_method_create_document_with_all_params(self, client: Casedev, respx_mock: MockRouter) -> None:
        respx_mock.post("/format/v1/document").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        v1 = client.format.v1.create_document(
            content="content",
            output_format="pdf",
            input_format="md",
            options={
                "components": [
                    {
                        "content": "content",
                        "styles": {},
                        "template_id": "templateId",
                        "variables": {},
                    }
                ]
            },
        )
        assert v1.is_closed
        assert v1.json() == {"foo": "bar"}
        assert cast(Any, v1.is_closed) is True
        assert isinstance(v1, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_raw_response_create_document(self, client: Casedev, respx_mock: MockRouter) -> None:
        respx_mock.post("/format/v1/document").mock(return_value=httpx.Response(200, json={"foo": "bar"}))

        v1 = client.format.v1.with_raw_response.create_document(
            content="content",
            output_format="pdf",
        )

        assert v1.is_closed is True
        assert v1.http_request.headers.get("X-Stainless-Lang") == "python"
        assert v1.json() == {"foo": "bar"}
        assert isinstance(v1, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_streaming_response_create_document(self, client: Casedev, respx_mock: MockRouter) -> None:
        respx_mock.post("/format/v1/document").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        with client.format.v1.with_streaming_response.create_document(
            content="content",
            output_format="pdf",
        ) as v1:
            assert not v1.is_closed
            assert v1.http_request.headers.get("X-Stainless-Lang") == "python"

            assert v1.json() == {"foo": "bar"}
            assert cast(Any, v1.is_closed) is True
            assert isinstance(v1, StreamedBinaryAPIResponse)

        assert cast(Any, v1.is_closed) is True


class TestAsyncV1:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_method_create_document(self, async_client: AsyncCasedev, respx_mock: MockRouter) -> None:
        respx_mock.post("/format/v1/document").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        v1 = await async_client.format.v1.create_document(
            content="content",
            output_format="pdf",
        )
        assert v1.is_closed
        assert await v1.json() == {"foo": "bar"}
        assert cast(Any, v1.is_closed) is True
        assert isinstance(v1, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_method_create_document_with_all_params(
        self, async_client: AsyncCasedev, respx_mock: MockRouter
    ) -> None:
        respx_mock.post("/format/v1/document").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        v1 = await async_client.format.v1.create_document(
            content="content",
            output_format="pdf",
            input_format="md",
            options={
                "components": [
                    {
                        "content": "content",
                        "styles": {},
                        "template_id": "templateId",
                        "variables": {},
                    }
                ]
            },
        )
        assert v1.is_closed
        assert await v1.json() == {"foo": "bar"}
        assert cast(Any, v1.is_closed) is True
        assert isinstance(v1, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_raw_response_create_document(self, async_client: AsyncCasedev, respx_mock: MockRouter) -> None:
        respx_mock.post("/format/v1/document").mock(return_value=httpx.Response(200, json={"foo": "bar"}))

        v1 = await async_client.format.v1.with_raw_response.create_document(
            content="content",
            output_format="pdf",
        )

        assert v1.is_closed is True
        assert v1.http_request.headers.get("X-Stainless-Lang") == "python"
        assert await v1.json() == {"foo": "bar"}
        assert isinstance(v1, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_streaming_response_create_document(self, async_client: AsyncCasedev, respx_mock: MockRouter) -> None:
        respx_mock.post("/format/v1/document").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        async with async_client.format.v1.with_streaming_response.create_document(
            content="content",
            output_format="pdf",
        ) as v1:
            assert not v1.is_closed
            assert v1.http_request.headers.get("X-Stainless-Lang") == "python"

            assert await v1.json() == {"foo": "bar"}
            assert cast(Any, v1.is_closed) is True
            assert isinstance(v1, AsyncStreamedBinaryAPIResponse)

        assert cast(Any, v1.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from casedev import Casedev, AsyncCasedev

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestInboxes:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: Casedev) -> None:
        inbox = client.mail.v1.inboxes.create()
        assert inbox is None

    @parametrize
    def test_method_create_with_all_params(self, client: Casedev) -> None:
        inbox = client.mail.v1.inboxes.create(
            address="address",
            display_name="displayName",
        )
        assert inbox is None

    @parametrize
    def test_raw_response_create(self, client: Casedev) -> None:
        response = client.mail.v1.inboxes.with_raw_response.create()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        inbox = response.parse()
        assert inbox is None

    @parametrize
    def test_streaming_response_create(self, client: Casedev) -> None:
        with client.mail.v1.inboxes.with_streaming_response.create() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            inbox = response.parse()
            assert inbox is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_retrieve(self, client: Casedev) -> None:
        inbox = client.mail.v1.inboxes.retrieve(
            "inboxId",
        )
        assert inbox is None

    @parametrize
    def test_raw_response_retrieve(self, client: Casedev) -> None:
        response = client.mail.v1.inboxes.with_raw_response.retrieve(
            "inboxId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        inbox = response.parse()
        assert inbox is None

    @parametrize
    def test_streaming_response_retrieve(self, client: Casedev) -> None:
        with client.mail.v1.inboxes.with_streaming_response.retrieve(
            "inboxId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            inbox = response.parse()
            assert inbox is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `inbox_id` but received ''"):
            client.mail.v1.inboxes.with_raw_response.retrieve(
                "",
            )

    @parametrize
    def test_method_list(self, client: Casedev) -> None:
        inbox = client.mail.v1.inboxes.list()
        assert inbox is None

    @parametrize
    def test_raw_response_list(self, client: Casedev) -> None:
        response = client.mail.v1.inboxes.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        inbox = response.parse()
        assert inbox is None

    @parametrize
    def test_streaming_response_list(self, client: Casedev) -> None:
        with client.mail.v1.inboxes.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            inbox = response.parse()
            assert inbox is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_delete(self, client: Casedev) -> None:
        inbox = client.mail.v1.inboxes.delete(
            "inboxId",
        )
        assert inbox is None

    @parametrize
    def test_raw_response_delete(self, client: Casedev) -> None:
        response = client.mail.v1.inboxes.with_raw_response.delete(
            "inboxId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        inbox = response.parse()
        assert inbox is None

    @parametrize
    def test_streaming_response_delete(self, client: Casedev) -> None:
        with client.mail.v1.inboxes.with_streaming_response.delete(
            "inboxId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            inbox = response.parse()
            assert inbox is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_delete(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `inbox_id` but received ''"):
            client.mail.v1.inboxes.with_raw_response.delete(
                "",
            )

    @parametrize
    def test_method_get_attachment(self, client: Casedev) -> None:
        inbox = client.mail.v1.inboxes.get_attachment(
            attachment_id="attachmentId",
            inbox_id="inboxId",
            message_id="messageId",
        )
        assert inbox is None

    @parametrize
    def test_raw_response_get_attachment(self, client: Casedev) -> None:
        response = client.mail.v1.inboxes.with_raw_response.get_attachment(
            attachment_id="attachmentId",
            inbox_id="inboxId",
            message_id="messageId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        inbox = response.parse()
        assert inbox is None

    @parametrize
    def test_streaming_response_get_attachment(self, client: Casedev) -> None:
        with client.mail.v1.inboxes.with_streaming_response.get_attachment(
            attachment_id="attachmentId",
            inbox_id="inboxId",
            message_id="messageId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            inbox = response.parse()
            assert inbox is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_get_attachment(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `inbox_id` but received ''"):
            client.mail.v1.inboxes.with_raw_response.get_attachment(
                attachment_id="attachmentId",
                inbox_id="",
                message_id="messageId",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `message_id` but received ''"):
            client.mail.v1.inboxes.with_raw_response.get_attachment(
                attachment_id="attachmentId",
                inbox_id="inboxId",
                message_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `attachment_id` but received ''"):
            client.mail.v1.inboxes.with_raw_response.get_attachment(
                attachment_id="",
                inbox_id="inboxId",
                message_id="messageId",
            )

    @parametrize
    def test_method_get_message(self, client: Casedev) -> None:
        inbox = client.mail.v1.inboxes.get_message(
            message_id="messageId",
            inbox_id="inboxId",
        )
        assert inbox is None

    @parametrize
    def test_raw_response_get_message(self, client: Casedev) -> None:
        response = client.mail.v1.inboxes.with_raw_response.get_message(
            message_id="messageId",
            inbox_id="inboxId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        inbox = response.parse()
        assert inbox is None

    @parametrize
    def test_streaming_response_get_message(self, client: Casedev) -> None:
        with client.mail.v1.inboxes.with_streaming_response.get_message(
            message_id="messageId",
            inbox_id="inboxId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            inbox = response.parse()
            assert inbox is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_get_message(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `inbox_id` but received ''"):
            client.mail.v1.inboxes.with_raw_response.get_message(
                message_id="messageId",
                inbox_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `message_id` but received ''"):
            client.mail.v1.inboxes.with_raw_response.get_message(
                message_id="",
                inbox_id="inboxId",
            )

    @parametrize
    def test_method_get_policy(self, client: Casedev) -> None:
        inbox = client.mail.v1.inboxes.get_policy(
            "inboxId",
        )
        assert inbox is None

    @parametrize
    def test_raw_response_get_policy(self, client: Casedev) -> None:
        response = client.mail.v1.inboxes.with_raw_response.get_policy(
            "inboxId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        inbox = response.parse()
        assert inbox is None

    @parametrize
    def test_streaming_response_get_policy(self, client: Casedev) -> None:
        with client.mail.v1.inboxes.with_streaming_response.get_policy(
            "inboxId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            inbox = response.parse()
            assert inbox is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_get_policy(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `inbox_id` but received ''"):
            client.mail.v1.inboxes.with_raw_response.get_policy(
                "",
            )

    @parametrize
    def test_method_list_messages(self, client: Casedev) -> None:
        inbox = client.mail.v1.inboxes.list_messages(
            "inboxId",
        )
        assert inbox is None

    @parametrize
    def test_raw_response_list_messages(self, client: Casedev) -> None:
        response = client.mail.v1.inboxes.with_raw_response.list_messages(
            "inboxId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        inbox = response.parse()
        assert inbox is None

    @parametrize
    def test_streaming_response_list_messages(self, client: Casedev) -> None:
        with client.mail.v1.inboxes.with_streaming_response.list_messages(
            "inboxId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            inbox = response.parse()
            assert inbox is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_list_messages(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `inbox_id` but received ''"):
            client.mail.v1.inboxes.with_raw_response.list_messages(
                "",
            )

    @parametrize
    def test_method_reply(self, client: Casedev) -> None:
        inbox = client.mail.v1.inboxes.reply(
            message_id="messageId",
            inbox_id="inboxId",
        )
        assert inbox is None

    @parametrize
    def test_raw_response_reply(self, client: Casedev) -> None:
        response = client.mail.v1.inboxes.with_raw_response.reply(
            message_id="messageId",
            inbox_id="inboxId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        inbox = response.parse()
        assert inbox is None

    @parametrize
    def test_streaming_response_reply(self, client: Casedev) -> None:
        with client.mail.v1.inboxes.with_streaming_response.reply(
            message_id="messageId",
            inbox_id="inboxId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            inbox = response.parse()
            assert inbox is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_reply(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `inbox_id` but received ''"):
            client.mail.v1.inboxes.with_raw_response.reply(
                message_id="messageId",
                inbox_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `message_id` but received ''"):
            client.mail.v1.inboxes.with_raw_response.reply(
                message_id="",
                inbox_id="inboxId",
            )

    @parametrize
    def test_method_send(self, client: Casedev) -> None:
        inbox = client.mail.v1.inboxes.send(
            "inboxId",
        )
        assert inbox is None

    @parametrize
    def test_raw_response_send(self, client: Casedev) -> None:
        response = client.mail.v1.inboxes.with_raw_response.send(
            "inboxId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        inbox = response.parse()
        assert inbox is None

    @parametrize
    def test_streaming_response_send(self, client: Casedev) -> None:
        with client.mail.v1.inboxes.with_streaming_response.send(
            "inboxId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            inbox = response.parse()
            assert inbox is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_send(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `inbox_id` but received ''"):
            client.mail.v1.inboxes.with_raw_response.send(
                "",
            )

    @parametrize
    def test_method_set_policy(self, client: Casedev) -> None:
        inbox = client.mail.v1.inboxes.set_policy(
            inbox_id="inboxId",
        )
        assert inbox is None

    @parametrize
    def test_method_set_policy_with_all_params(self, client: Casedev) -> None:
        inbox = client.mail.v1.inboxes.set_policy(
            inbox_id="inboxId",
            allowed_sender_patterns=["string"],
            enforce_sender_allowlist=True,
            read_access_rules=["string"],
            reply_access_rules=["string"],
            send_access_rules=["string"],
        )
        assert inbox is None

    @parametrize
    def test_raw_response_set_policy(self, client: Casedev) -> None:
        response = client.mail.v1.inboxes.with_raw_response.set_policy(
            inbox_id="inboxId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        inbox = response.parse()
        assert inbox is None

    @parametrize
    def test_streaming_response_set_policy(self, client: Casedev) -> None:
        with client.mail.v1.inboxes.with_streaming_response.set_policy(
            inbox_id="inboxId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            inbox = response.parse()
            assert inbox is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_set_policy(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `inbox_id` but received ''"):
            client.mail.v1.inboxes.with_raw_response.set_policy(
                inbox_id="",
            )


class TestAsyncInboxes:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_create(self, async_client: AsyncCasedev) -> None:
        inbox = await async_client.mail.v1.inboxes.create()
        assert inbox is None

    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncCasedev) -> None:
        inbox = await async_client.mail.v1.inboxes.create(
            address="address",
            display_name="displayName",
        )
        assert inbox is None

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncCasedev) -> None:
        response = await async_client.mail.v1.inboxes.with_raw_response.create()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        inbox = await response.parse()
        assert inbox is None

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncCasedev) -> None:
        async with async_client.mail.v1.inboxes.with_streaming_response.create() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            inbox = await response.parse()
            assert inbox is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncCasedev) -> None:
        inbox = await async_client.mail.v1.inboxes.retrieve(
            "inboxId",
        )
        assert inbox is None

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncCasedev) -> None:
        response = await async_client.mail.v1.inboxes.with_raw_response.retrieve(
            "inboxId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        inbox = await response.parse()
        assert inbox is None

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncCasedev) -> None:
        async with async_client.mail.v1.inboxes.with_streaming_response.retrieve(
            "inboxId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            inbox = await response.parse()
            assert inbox is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `inbox_id` but received ''"):
            await async_client.mail.v1.inboxes.with_raw_response.retrieve(
                "",
            )

    @parametrize
    async def test_method_list(self, async_client: AsyncCasedev) -> None:
        inbox = await async_client.mail.v1.inboxes.list()
        assert inbox is None

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncCasedev) -> None:
        response = await async_client.mail.v1.inboxes.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        inbox = await response.parse()
        assert inbox is None

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncCasedev) -> None:
        async with async_client.mail.v1.inboxes.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            inbox = await response.parse()
            assert inbox is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_delete(self, async_client: AsyncCasedev) -> None:
        inbox = await async_client.mail.v1.inboxes.delete(
            "inboxId",
        )
        assert inbox is None

    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncCasedev) -> None:
        response = await async_client.mail.v1.inboxes.with_raw_response.delete(
            "inboxId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        inbox = await response.parse()
        assert inbox is None

    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncCasedev) -> None:
        async with async_client.mail.v1.inboxes.with_streaming_response.delete(
            "inboxId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            inbox = await response.parse()
            assert inbox is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_delete(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `inbox_id` but received ''"):
            await async_client.mail.v1.inboxes.with_raw_response.delete(
                "",
            )

    @parametrize
    async def test_method_get_attachment(self, async_client: AsyncCasedev) -> None:
        inbox = await async_client.mail.v1.inboxes.get_attachment(
            attachment_id="attachmentId",
            inbox_id="inboxId",
            message_id="messageId",
        )
        assert inbox is None

    @parametrize
    async def test_raw_response_get_attachment(self, async_client: AsyncCasedev) -> None:
        response = await async_client.mail.v1.inboxes.with_raw_response.get_attachment(
            attachment_id="attachmentId",
            inbox_id="inboxId",
            message_id="messageId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        inbox = await response.parse()
        assert inbox is None

    @parametrize
    async def test_streaming_response_get_attachment(self, async_client: AsyncCasedev) -> None:
        async with async_client.mail.v1.inboxes.with_streaming_response.get_attachment(
            attachment_id="attachmentId",
            inbox_id="inboxId",
            message_id="messageId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            inbox = await response.parse()
            assert inbox is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_get_attachment(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `inbox_id` but received ''"):
            await async_client.mail.v1.inboxes.with_raw_response.get_attachment(
                attachment_id="attachmentId",
                inbox_id="",
                message_id="messageId",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `message_id` but received ''"):
            await async_client.mail.v1.inboxes.with_raw_response.get_attachment(
                attachment_id="attachmentId",
                inbox_id="inboxId",
                message_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `attachment_id` but received ''"):
            await async_client.mail.v1.inboxes.with_raw_response.get_attachment(
                attachment_id="",
                inbox_id="inboxId",
                message_id="messageId",
            )

    @parametrize
    async def test_method_get_message(self, async_client: AsyncCasedev) -> None:
        inbox = await async_client.mail.v1.inboxes.get_message(
            message_id="messageId",
            inbox_id="inboxId",
        )
        assert inbox is None

    @parametrize
    async def test_raw_response_get_message(self, async_client: AsyncCasedev) -> None:
        response = await async_client.mail.v1.inboxes.with_raw_response.get_message(
            message_id="messageId",
            inbox_id="inboxId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        inbox = await response.parse()
        assert inbox is None

    @parametrize
    async def test_streaming_response_get_message(self, async_client: AsyncCasedev) -> None:
        async with async_client.mail.v1.inboxes.with_streaming_response.get_message(
            message_id="messageId",
            inbox_id="inboxId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            inbox = await response.parse()
            assert inbox is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_get_message(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `inbox_id` but received ''"):
            await async_client.mail.v1.inboxes.with_raw_response.get_message(
                message_id="messageId",
                inbox_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `message_id` but received ''"):
            await async_client.mail.v1.inboxes.with_raw_response.get_message(
                message_id="",
                inbox_id="inboxId",
            )

    @parametrize
    async def test_method_get_policy(self, async_client: AsyncCasedev) -> None:
        inbox = await async_client.mail.v1.inboxes.get_policy(
            "inboxId",
        )
        assert inbox is None

    @parametrize
    async def test_raw_response_get_policy(self, async_client: AsyncCasedev) -> None:
        response = await async_client.mail.v1.inboxes.with_raw_response.get_policy(
            "inboxId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        inbox = await response.parse()
        assert inbox is None

    @parametrize
    async def test_streaming_response_get_policy(self, async_client: AsyncCasedev) -> None:
        async with async_client.mail.v1.inboxes.with_streaming_response.get_policy(
            "inboxId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            inbox = await response.parse()
            assert inbox is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_get_policy(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `inbox_id` but received ''"):
            await async_client.mail.v1.inboxes.with_raw_response.get_policy(
                "",
            )

    @parametrize
    async def test_method_list_messages(self, async_client: AsyncCasedev) -> None:
        inbox = await async_client.mail.v1.inboxes.list_messages(
            "inboxId",
        )
        assert inbox is None

    @parametrize
    async def test_raw_response_list_messages(self, async_client: AsyncCasedev) -> None:
        response = await async_client.mail.v1.inboxes.with_raw_response.list_messages(
            "inboxId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        inbox = await response.parse()
        assert inbox is None

    @parametrize
    async def test_streaming_response_list_messages(self, async_client: AsyncCasedev) -> None:
        async with async_client.mail.v1.inboxes.with_streaming_response.list_messages(
            "inboxId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            inbox = await response.parse()
            assert inbox is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_list_messages(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `inbox_id` but received ''"):
            await async_client.mail.v1.inboxes.with_raw_response.list_messages(
                "",
            )

    @parametrize
    async def test_method_reply(self, async_client: AsyncCasedev) -> None:
        inbox = await async_client.mail.v1.inboxes.reply(
            message_id="messageId",
            inbox_id="inboxId",
        )
        assert inbox is None

    @parametrize
    async def test_raw_response_reply(self, async_client: AsyncCasedev) -> None:
        response = await async_client.mail.v1.inboxes.with_raw_response.reply(
            message_id="messageId",
            inbox_id="inboxId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        inbox = await response.parse()
        assert inbox is None

    @parametrize
    async def test_streaming_response_reply(self, async_client: AsyncCasedev) -> None:
        async with async_client.mail.v1.inboxes.with_streaming_response.reply(
            message_id="messageId",
            inbox_id="inboxId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            inbox = await response.parse()
            assert inbox is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_reply(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `inbox_id` but received ''"):
            await async_client.mail.v1.inboxes.with_raw_response.reply(
                message_id="messageId",
                inbox_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `message_id` but received ''"):
            await async_client.mail.v1.inboxes.with_raw_response.reply(
                message_id="",
                inbox_id="inboxId",
            )

    @parametrize
    async def test_method_send(self, async_client: AsyncCasedev) -> None:
        inbox = await async_client.mail.v1.inboxes.send(
            "inboxId",
        )
        assert inbox is None

    @parametrize
    async def test_raw_response_send(self, async_client: AsyncCasedev) -> None:
        response = await async_client.mail.v1.inboxes.with_raw_response.send(
            "inboxId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        inbox = await response.parse()
        assert inbox is None

    @parametrize
    async def test_streaming_response_send(self, async_client: AsyncCasedev) -> None:
        async with async_client.mail.v1.inboxes.with_streaming_response.send(
            "inboxId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            inbox = await response.parse()
            assert inbox is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_send(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `inbox_id` but received ''"):
            await async_client.mail.v1.inboxes.with_raw_response.send(
                "",
            )

    @parametrize
    async def test_method_set_policy(self, async_client: AsyncCasedev) -> None:
        inbox = await async_client.mail.v1.inboxes.set_policy(
            inbox_id="inboxId",
        )
        assert inbox is None

    @parametrize
    async def test_method_set_policy_with_all_params(self, async_client: AsyncCasedev) -> None:
        inbox = await async_client.mail.v1.inboxes.set_policy(
            inbox_id="inboxId",
            allowed_sender_patterns=["string"],
            enforce_sender_allowlist=True,
            read_access_rules=["string"],
            reply_access_rules=["string"],
            send_access_rules=["string"],
        )
        assert inbox is None

    @parametrize
    async def test_raw_response_set_policy(self, async_client: AsyncCasedev) -> None:
        response = await async_client.mail.v1.inboxes.with_raw_response.set_policy(
            inbox_id="inboxId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        inbox = await response.parse()
        assert inbox is None

    @parametrize
    async def test_streaming_response_set_policy(self, async_client: AsyncCasedev) -> None:
        async with async_client.mail.v1.inboxes.with_streaming_response.set_policy(
            inbox_id="inboxId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            inbox = await response.parse()
            assert inbox is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_set_policy(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `inbox_id` but received ''"):
            await async_client.mail.v1.inboxes.with_raw_response.set_policy(
                inbox_id="",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from casedev import Casedev, AsyncCasedev
from tests.utils import assert_matches_type
from casedev._utils import parse_date
from casedev.types.search import (
    V1AnswerResponse,
    V1SearchResponse,
    V1SimilarResponse,
    V1ContentsResponse,
    V1ResearchResponse,
    V1RetrieveResearchResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestV1:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_answer(self, client: Casedev) -> None:
        v1 = client.search.v1.answer(
            query="query",
        )
        assert_matches_type(V1AnswerResponse, v1, path=["response"])

    @parametrize
    def test_method_answer_with_all_params(self, client: Casedev) -> None:
        v1 = client.search.v1.answer(
            query="query",
            exclude_domains=["string"],
            include_domains=["string"],
            max_tokens=0,
            model="model",
            num_results=1,
            search_type="auto",
            stream=True,
            temperature=0,
            text=True,
            use_custom_llm=True,
        )
        assert_matches_type(V1AnswerResponse, v1, path=["response"])

    @parametrize
    def test_raw_response_answer(self, client: Casedev) -> None:
        response = client.search.v1.with_raw_response.answer(
            query="query",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1AnswerResponse, v1, path=["response"])

    @parametrize
    def test_streaming_response_answer(self, client: Casedev) -> None:
        with client.search.v1.with_streaming_response.answer(
            query="query",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1AnswerResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_contents(self, client: Casedev) -> None:
        v1 = client.search.v1.contents(
            urls=["https://example.com"],
        )
        assert_matches_type(V1ContentsResponse, v1, path=["response"])

    @parametrize
    def test_method_contents_with_all_params(self, client: Casedev) -> None:
        v1 = client.search.v1.contents(
            urls=["https://example.com"],
            context="context",
            extras={},
            highlights=True,
            livecrawl=True,
            livecrawl_timeout=0,
            subpages=True,
            subpage_target=0,
            summary=True,
            text=True,
        )
        assert_matches_type(V1ContentsResponse, v1, path=["response"])

    @parametrize
    def test_raw_response_contents(self, client: Casedev) -> None:
        response = client.search.v1.with_raw_response.contents(
            urls=["https://example.com"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1ContentsResponse, v1, path=["response"])

    @parametrize
    def test_streaming_response_contents(self, client: Casedev) -> None:
        with client.search.v1.with_streaming_response.contents(
            urls=["https://example.com"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1ContentsResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_research(self, client: Casedev) -> None:
        v1 = client.search.v1.research(
            instructions="instructions",
        )
        assert_matches_type(V1ResearchResponse, v1, path=["response"])

    @parametrize
    def test_method_research_with_all_params(self, client: Casedev) -> None:
        v1 = client.search.v1.research(
            instructions="instructions",
            model="fast",
            output_schema={},
            query="query",
        )
        assert_matches_type(V1ResearchResponse, v1, path=["response"])

    @parametrize
    def test_raw_response_research(self, client: Casedev) -> None:
        response = client.search.v1.with_raw_response.research(
            instructions="instructions",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1ResearchResponse, v1, path=["response"])

    @parametrize
    def test_streaming_response_research(self, client: Casedev) -> None:
        with client.search.v1.with_streaming_response.research(
            instructions="instructions",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1ResearchResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_retrieve_research(self, client: Casedev) -> None:
        v1 = client.search.v1.retrieve_research(
            id="id",
        )
        assert_matches_type(V1RetrieveResearchResponse, v1, path=["response"])

    @parametrize
    def test_method_retrieve_research_with_all_params(self, client: Casedev) -> None:
        v1 = client.search.v1.retrieve_research(
            id="id",
            events="events",
            stream=True,
        )
        assert_matches_type(V1RetrieveResearchResponse, v1, path=["response"])

    @parametrize
    def test_raw_response_retrieve_research(self, client: Casedev) -> None:
        response = client.search.v1.with_raw_response.retrieve_research(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1RetrieveResearchResponse, v1, path=["response"])

    @parametrize
    def test_streaming_response_retrieve_research(self, client: Casedev) -> None:
        with client.search.v1.with_streaming_response.retrieve_research(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1RetrieveResearchResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve_research(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.search.v1.with_raw_response.retrieve_research(
                id="",
            )

    @parametrize
    def test_method_search(self, client: Casedev) -> None:
        v1 = client.search.v1.search(
            query="query",
        )
        assert_matches_type(V1SearchResponse, v1, path=["response"])

    @parametrize
    def test_method_search_with_all_params(self, client: Casedev) -> None:
        v1 = client.search.v1.search(
            query="query",
            additional_queries=["string"],
            category="category",
            contents="contents",
            end_crawl_date=parse_date("2019-12-27"),
            end_published_date=parse_date("2019-12-27"),
            exclude_domains=["string"],
            include_domains=["string"],
            include_text=True,
            num_results=1,
            start_crawl_date=parse_date("2019-12-27"),
            start_published_date=parse_date("2019-12-27"),
            type="auto",
            user_location="userLocation",
        )
        assert_matches_type(V1SearchResponse, v1, path=["response"])

    @parametrize
    def test_raw_response_search(self, client: Casedev) -> None:
        response = client.search.v1.with_raw_response.search(
            query="query",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1SearchResponse, v1, path=["response"])

    @parametrize
    def test_streaming_response_search(self, client: Casedev) -> None:
        with client.search.v1.with_streaming_response.search(
            query="query",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1SearchResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_similar(self, client: Casedev) -> None:
        v1 = client.search.v1.similar(
            url="https://example.com",
        )
        assert_matches_type(V1SimilarResponse, v1, path=["response"])

    @parametrize
    def test_method_similar_with_all_params(self, client: Casedev) -> None:
        v1 = client.search.v1.similar(
            url="https://example.com",
            contents="contents",
            end_crawl_date=parse_date("2019-12-27"),
            end_published_date=parse_date("2019-12-27"),
            exclude_domains=["string"],
            include_domains=["string"],
            include_text=True,
            num_results=1,
            start_crawl_date=parse_date("2019-12-27"),
            start_published_date=parse_date("2019-12-27"),
        )
        assert_matches_type(V1SimilarResponse, v1, path=["response"])

    @parametrize
    def test_raw_response_similar(self, client: Casedev) -> None:
        response = client.search.v1.with_raw_response.similar(
            url="https://example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1SimilarResponse, v1, path=["response"])

    @parametrize
    def test_streaming_response_similar(self, client: Casedev) -> None:
        with client.search.v1.with_streaming_response.similar(
            url="https://example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1SimilarResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncV1:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_answer(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.search.v1.answer(
            query="query",
        )
        assert_matches_type(V1AnswerResponse, v1, path=["response"])

    @parametrize
    async def test_method_answer_with_all_params(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.search.v1.answer(
            query="query",
            exclude_domains=["string"],
            include_domains=["string"],
            max_tokens=0,
            model="model",
            num_results=1,
            search_type="auto",
            stream=True,
            temperature=0,
            text=True,
            use_custom_llm=True,
        )
        assert_matches_type(V1AnswerResponse, v1, path=["response"])

    @parametrize
    async def test_raw_response_answer(self, async_client: AsyncCasedev) -> None:
        response = await async_client.search.v1.with_raw_response.answer(
            query="query",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1AnswerResponse, v1, path=["response"])

    @parametrize
    async def test_streaming_response_answer(self, async_client: AsyncCasedev) -> None:
        async with async_client.search.v1.with_streaming_response.answer(
            query="query",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1AnswerResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_contents(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.search.v1.contents(
            urls=["https://example.com"],
        )
        assert_matches_type(V1ContentsResponse, v1, path=["response"])

    @parametrize
    async def test_method_contents_with_all_params(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.search.v1.contents(
            urls=["https://example.com"],
            context="context",
            extras={},
            highlights=True,
            livecrawl=True,
            livecrawl_timeout=0,
            subpages=True,
            subpage_target=0,
            summary=True,
            text=True,
        )
        assert_matches_type(V1ContentsResponse, v1, path=["response"])

    @parametrize
    async def test_raw_response_contents(self, async_client: AsyncCasedev) -> None:
        response = await async_client.search.v1.with_raw_response.contents(
            urls=["https://example.com"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1ContentsResponse, v1, path=["response"])

    @parametrize
    async def test_streaming_response_contents(self, async_client: AsyncCasedev) -> None:
        async with async_client.search.v1.with_streaming_response.contents(
            urls=["https://example.com"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1ContentsResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_research(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.search.v1.research(
            instructions="instructions",
        )
        assert_matches_type(V1ResearchResponse, v1, path=["response"])

    @parametrize
    async def test_method_research_with_all_params(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.search.v1.research(
            instructions="instructions",
            model="fast",
            output_schema={},
            query="query",
        )
        assert_matches_type(V1ResearchResponse, v1, path=["response"])

    @parametrize
    async def test_raw_response_research(self, async_client: AsyncCasedev) -> None:
        response = await async_client.search.v1.with_raw_response.research(
            instructions="instructions",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1ResearchResponse, v1, path=["response"])

    @parametrize
    async def test_streaming_response_research(self, async_client: AsyncCasedev) -> None:
        async with async_client.search.v1.with_streaming_response.research(
            instructions="instructions",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1ResearchResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_retrieve_research(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.search.v1.retrieve_research(
            id="id",
        )
        assert_matches_type(V1RetrieveResearchResponse, v1, path=["response"])

    @parametrize
    async def test_method_retrieve_research_with_all_params(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.search.v1.retrieve_research(
            id="id",
            events="events",
            stream=True,
        )
        assert_matches_type(V1RetrieveResearchResponse, v1, path=["response"])

    @parametrize
    async def test_raw_response_retrieve_research(self, async_client: AsyncCasedev) -> None:
        response = await async_client.search.v1.with_raw_response.retrieve_research(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1RetrieveResearchResponse, v1, path=["response"])

    @parametrize
    async def test_streaming_response_retrieve_research(self, async_client: AsyncCasedev) -> None:
        async with async_client.search.v1.with_streaming_response.retrieve_research(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1RetrieveResearchResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve_research(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.search.v1.with_raw_response.retrieve_research(
                id="",
            )

    @parametrize
    async def test_method_search(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.search.v1.search(
            query="query",
        )
        assert_matches_type(V1SearchResponse, v1, path=["response"])

    @parametrize
    async def test_method_search_with_all_params(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.search.v1.search(
            query="query",
            additional_queries=["string"],
            category="category",
            contents="contents",
            end_crawl_date=parse_date("2019-12-27"),
            end_published_date=parse_date("2019-12-27"),
            exclude_domains=["string"],
            include_domains=["string"],
            include_text=True,
            num_results=1,
            start_crawl_date=parse_date("2019-12-27"),
            start_published_date=parse_date("2019-12-27"),
            type="auto",
            user_location="userLocation",
        )
        assert_matches_type(V1SearchResponse, v1, path=["response"])

    @parametrize
    async def test_raw_response_search(self, async_client: AsyncCasedev) -> None:
        response = await async_client.search.v1.with_raw_response.search(
            query="query",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1SearchResponse, v1, path=["response"])

    @parametrize
    async def test_streaming_response_search(self, async_client: AsyncCasedev) -> None:
        async with async_client.search.v1.with_streaming_response.search(
            query="query",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1SearchResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_similar(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.search.v1.similar(
            url="https://example.com",
        )
        assert_matches_type(V1SimilarResponse, v1, path=["response"])

    @parametrize
    async def test_method_similar_with_all_params(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.search.v1.similar(
            url="https://example.com",
            contents="contents",
            end_crawl_date=parse_date("2019-12-27"),
            end_published_date=parse_date("2019-12-27"),
            exclude_domains=["string"],
            include_domains=["string"],
            include_text=True,
            num_results=1,
            start_crawl_date=parse_date("2019-12-27"),
            start_published_date=parse_date("2019-12-27"),
        )
        assert_matches_type(V1SimilarResponse, v1, path=["response"])

    @parametrize
    async def test_raw_response_similar(self, async_client: AsyncCasedev) -> None:
        response = await async_client.search.v1.with_raw_response.similar(
            url="https://example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1SimilarResponse, v1, path=["response"])

    @parametrize
    async def test_streaming_response_similar(self, async_client: AsyncCasedev) -> None:
        async with async_client.search.v1.with_streaming_response.similar(
            url="https://example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1SimilarResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .v1.v1 import (
    V1Resource,
    AsyncV1Resource,
    V1ResourceWithRawResponse,
    AsyncV1ResourceWithRawResponse,
    V1ResourceWithStreamingResponse,
    AsyncV1ResourceWithStreamingResponse,
)
from ..._types import Body, Query, Headers, NotGiven, not_given
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.llm_get_config_response import LlmGetConfigResponse

__all__ = ["LlmResource", "AsyncLlmResource"]


class LlmResource(SyncAPIResource):
    """Access 40+ language models through a unified API"""

    @cached_property
    def v1(self) -> V1Resource:
        """Access 40+ language models through a unified API"""
        return V1Resource(self._client)

    @cached_property
    def with_raw_response(self) -> LlmResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return LlmResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> LlmResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return LlmResourceWithStreamingResponse(self)

    def get_config(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LlmGetConfigResponse:
        """
        Retrieves the AI Gateway configuration including all available language models
        and their specifications. This endpoint returns model information compatible
        with the Vercel AI SDK Gateway format, making it easy to integrate with existing
        AI applications.

        Use this endpoint to:

        - Discover available language models
        - Get model specifications and pricing
        - Configure AI SDK clients
        - Build model selection interfaces
        """
        return self._get(
            "/llm/config",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LlmGetConfigResponse,
        )


class AsyncLlmResource(AsyncAPIResource):
    """Access 40+ language models through a unified API"""

    @cached_property
    def v1(self) -> AsyncV1Resource:
        """Access 40+ language models through a unified API"""
        return AsyncV1Resource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncLlmResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return AsyncLlmResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncLlmResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return AsyncLlmResourceWithStreamingResponse(self)

    async def get_config(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LlmGetConfigResponse:
        """
        Retrieves the AI Gateway configuration including all available language models
        and their specifications. This endpoint returns model information compatible
        with the Vercel AI SDK Gateway format, making it easy to integrate with existing
        AI applications.

        Use this endpoint to:

        - Discover available language models
        - Get model specifications and pricing
        - Configure AI SDK clients
        - Build model selection interfaces
        """
        return await self._get(
            "/llm/config",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LlmGetConfigResponse,
        )


class LlmResourceWithRawResponse:
    def __init__(self, llm: LlmResource) -> None:
        self._llm = llm

        self.get_config = to_raw_response_wrapper(
            llm.get_config,
        )

    @cached_property
    def v1(self) -> V1ResourceWithRawResponse:
        """Access 40+ language models through a unified API"""
        return V1ResourceWithRawResponse(self._llm.v1)


class AsyncLlmResourceWithRawResponse:
    def __init__(self, llm: AsyncLlmResource) -> None:
        self._llm = llm

        self.get_config = async_to_raw_response_wrapper(
            llm.get_config,
        )

    @cached_property
    def v1(self) -> AsyncV1ResourceWithRawResponse:
        """Access 40+ language models through a unified API"""
        return AsyncV1ResourceWithRawResponse(self._llm.v1)


class LlmResourceWithStreamingResponse:
    def __init__(self, llm: LlmResource) -> None:
        self._llm = llm

        self.get_config = to_streamed_response_wrapper(
            llm.get_config,
        )

    @cached_property
    def v1(self) -> V1ResourceWithStreamingResponse:
        """Access 40+ language models through a unified API"""
        return V1ResourceWithStreamingResponse(self._llm.v1)


class AsyncLlmResourceWithStreamingResponse:
    def __init__(self, llm: AsyncLlmResource) -> None:
        self._llm = llm

        self.get_config = async_to_streamed_response_wrapper(
            llm.get_config,
        )

    @cached_property
    def v1(self) -> AsyncV1ResourceWithStreamingResponse:
        """Access 40+ language models through a unified API"""
        return AsyncV1ResourceWithStreamingResponse(self._llm.v1)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from casedev import Casedev, AsyncCasedev
from tests.utils import assert_matches_type
from casedev.types.voice import (
    BoostListExtractResponse,
    BoostListGenerateResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestBoostList:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_extract(self, client: Casedev) -> None:
        boost_list = client.voice.boost_list.extract()
        assert_matches_type(BoostListExtractResponse, boost_list, path=["response"])

    @parametrize
    def test_method_extract_with_all_params(self, client: Casedev) -> None:
        boost_list = client.voice.boost_list.extract(
            categories=["person"],
            object_ids=["string"],
            text="text",
            vault_id="vault_id",
        )
        assert_matches_type(BoostListExtractResponse, boost_list, path=["response"])

    @parametrize
    def test_raw_response_extract(self, client: Casedev) -> None:
        response = client.voice.boost_list.with_raw_response.extract()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        boost_list = response.parse()
        assert_matches_type(BoostListExtractResponse, boost_list, path=["response"])

    @parametrize
    def test_streaming_response_extract(self, client: Casedev) -> None:
        with client.voice.boost_list.with_streaming_response.extract() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            boost_list = response.parse()
            assert_matches_type(BoostListExtractResponse, boost_list, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_generate(self, client: Casedev) -> None:
        boost_list = client.voice.boost_list.generate(
            transcription_job_id="transcription_job_id",
        )
        assert_matches_type(BoostListGenerateResponse, boost_list, path=["response"])

    @parametrize
    def test_method_generate_with_all_params(self, client: Casedev) -> None:
        boost_list = client.voice.boost_list.generate(
            transcription_job_id="transcription_job_id",
            categories=["person"],
        )
        assert_matches_type(BoostListGenerateResponse, boost_list, path=["response"])

    @parametrize
    def test_raw_response_generate(self, client: Casedev) -> None:
        response = client.voice.boost_list.with_raw_response.generate(
            transcription_job_id="transcription_job_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        boost_list = response.parse()
        assert_matches_type(BoostListGenerateResponse, boost_list, path=["response"])

    @parametrize
    def test_streaming_response_generate(self, client: Casedev) -> None:
        with client.voice.boost_list.with_streaming_response.generate(
            transcription_job_id="transcription_job_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            boost_list = response.parse()
            assert_matches_type(BoostListGenerateResponse, boost_list, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncBoostList:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_extract(self, async_client: AsyncCasedev) -> None:
        boost_list = await async_client.voice.boost_list.extract()
        assert_matches_type(BoostListExtractResponse, boost_list, path=["response"])

    @parametrize
    async def test_method_extract_with_all_params(self, async_client: AsyncCasedev) -> None:
        boost_list = await async_client.voice.boost_list.extract(
            categories=["person"],
            object_ids=["string"],
            text="text",
            vault_id="vault_id",
        )
        assert_matches_type(BoostListExtractResponse, boost_list, path=["response"])

    @parametrize
    async def test_raw_response_extract(self, async_client: AsyncCasedev) -> None:
        response = await async_client.voice.boost_list.with_raw_response.extract()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        boost_list = await response.parse()
        assert_matches_type(BoostListExtractResponse, boost_list, path=["response"])

    @parametrize
    async def test_streaming_response_extract(self, async_client: AsyncCasedev) -> None:
        async with async_client.voice.boost_list.with_streaming_response.extract() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            boost_list = await response.parse()
            assert_matches_type(BoostListExtractResponse, boost_list, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_generate(self, async_client: AsyncCasedev) -> None:
        boost_list = await async_client.voice.boost_list.generate(
            transcription_job_id="transcription_job_id",
        )
        assert_matches_type(BoostListGenerateResponse, boost_list, path=["response"])

    @parametrize
    async def test_method_generate_with_all_params(self, async_client: AsyncCasedev) -> None:
        boost_list = await async_client.voice.boost_list.generate(
            transcription_job_id="transcription_job_id",
            categories=["person"],
        )
        assert_matches_type(BoostListGenerateResponse, boost_list, path=["response"])

    @parametrize
    async def test_raw_response_generate(self, async_client: AsyncCasedev) -> None:
        response = await async_client.voice.boost_list.with_raw_response.generate(
            transcription_job_id="transcription_job_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        boost_list = await response.parse()
        assert_matches_type(BoostListGenerateResponse, boost_list, path=["response"])

    @parametrize
    async def test_streaming_response_generate(self, async_client: AsyncCasedev) -> None:
        async with async_client.voice.boost_list.with_streaming_response.generate(
            transcription_job_id="transcription_job_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            boost_list = await response.parse()
            assert_matches_type(BoostListGenerateResponse, boost_list, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from .._models import BaseModel

__all__ = ["SkillCreateResponse"]


class SkillCreateResponse(BaseModel):
    content: Optional[str] = None

    created_at: Optional[datetime] = None

    metadata: Optional[object] = None

    name: Optional[str] = None

    slug: Optional[str] = None

    summary: Optional[str] = None

    tags: Optional[List[str]] = None

    version: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["VaultRetrieveResponse", "ChunkStrategy"]


class ChunkStrategy(BaseModel):
    """Document chunking strategy configuration"""

    chunk_size: Optional[int] = FieldInfo(alias="chunkSize", default=None)
    """Target size for each chunk in tokens"""

    method: Optional[str] = None
    """Chunking method (e.g., 'semantic', 'fixed')"""

    min_chunk_size: Optional[int] = FieldInfo(alias="minChunkSize", default=None)
    """Minimum chunk size in tokens"""

    overlap: Optional[int] = None
    """Number of overlapping tokens between chunks"""


class VaultRetrieveResponse(BaseModel):
    id: str
    """Vault identifier"""

    created_at: datetime = FieldInfo(alias="createdAt")
    """Vault creation timestamp"""

    files_bucket: str = FieldInfo(alias="filesBucket")
    """S3 bucket for document storage"""

    name: str
    """Vault name"""

    region: str
    """AWS region"""

    chunk_strategy: Optional[ChunkStrategy] = FieldInfo(alias="chunkStrategy", default=None)
    """Document chunking strategy configuration"""

    description: Optional[str] = None
    """Vault description"""

    enable_graph: Optional[bool] = FieldInfo(alias="enableGraph", default=None)
    """Whether GraphRAG is enabled"""

    index_name: Optional[str] = FieldInfo(alias="indexName", default=None)
    """Search index name"""

    kms_key_id: Optional[str] = FieldInfo(alias="kmsKeyId", default=None)
    """KMS key for encryption"""

    metadata: Optional[object] = None
    """Additional vault metadata"""

    total_bytes: Optional[int] = FieldInfo(alias="totalBytes", default=None)
    """Total storage size in bytes"""

    total_objects: Optional[int] = FieldInfo(alias="totalObjects", default=None)
    """Number of stored documents"""

    total_vectors: Optional[int] = FieldInfo(alias="totalVectors", default=None)
    """Number of vector embeddings"""

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Last update timestamp"""

    vector_bucket: Optional[str] = FieldInfo(alias="vectorBucket", default=None)
    """S3 bucket for vector embeddings"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["AgentRetrieveResponse"]


class AgentRetrieveResponse(BaseModel):
    id: Optional[str] = None

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)

    description: Optional[str] = None

    disabled_tools: Optional[List[str]] = FieldInfo(alias="disabledTools", default=None)

    enabled_tools: Optional[List[str]] = FieldInfo(alias="enabledTools", default=None)

    instructions: Optional[str] = None

    is_active: Optional[bool] = FieldInfo(alias="isActive", default=None)

    model: Optional[str] = None

    name: Optional[str] = None

    sandbox: Optional[object] = None

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)

    vault_ids: Optional[List[str]] = FieldInfo(alias="vaultIds", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from casedev import Casedev, AsyncCasedev

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestMatterParties:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: Casedev) -> None:
        matter_party = client.matters.v1.matter_parties.create(
            id="id",
            party_id="party_id",
            role="client",
        )
        assert matter_party is None

    @parametrize
    def test_method_create_with_all_params(self, client: Casedev) -> None:
        matter_party = client.matters.v1.matter_parties.create(
            id="id",
            party_id="party_id",
            role="client",
            custom_fields={"foo": "bar"},
            is_primary=True,
            metadata={"foo": "bar"},
            notes="notes",
            set_as_client=True,
        )
        assert matter_party is None

    @parametrize
    def test_raw_response_create(self, client: Casedev) -> None:
        response = client.matters.v1.matter_parties.with_raw_response.create(
            id="id",
            party_id="party_id",
            role="client",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        matter_party = response.parse()
        assert matter_party is None

    @parametrize
    def test_streaming_response_create(self, client: Casedev) -> None:
        with client.matters.v1.matter_parties.with_streaming_response.create(
            id="id",
            party_id="party_id",
            role="client",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            matter_party = response.parse()
            assert matter_party is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_create(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.matters.v1.matter_parties.with_raw_response.create(
                id="",
                party_id="party_id",
                role="client",
            )

    @parametrize
    def test_method_list(self, client: Casedev) -> None:
        matter_party = client.matters.v1.matter_parties.list(
            "id",
        )
        assert matter_party is None

    @parametrize
    def test_raw_response_list(self, client: Casedev) -> None:
        response = client.matters.v1.matter_parties.with_raw_response.list(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        matter_party = response.parse()
        assert matter_party is None

    @parametrize
    def test_streaming_response_list(self, client: Casedev) -> None:
        with client.matters.v1.matter_parties.with_streaming_response.list(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            matter_party = response.parse()
            assert matter_party is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_list(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.matters.v1.matter_parties.with_raw_response.list(
                "",
            )


class TestAsyncMatterParties:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_create(self, async_client: AsyncCasedev) -> None:
        matter_party = await async_client.matters.v1.matter_parties.create(
            id="id",
            party_id="party_id",
            role="client",
        )
        assert matter_party is None

    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncCasedev) -> None:
        matter_party = await async_client.matters.v1.matter_parties.create(
            id="id",
            party_id="party_id",
            role="client",
            custom_fields={"foo": "bar"},
            is_primary=True,
            metadata={"foo": "bar"},
            notes="notes",
            set_as_client=True,
        )
        assert matter_party is None

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncCasedev) -> None:
        response = await async_client.matters.v1.matter_parties.with_raw_response.create(
            id="id",
            party_id="party_id",
            role="client",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        matter_party = await response.parse()
        assert matter_party is None

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncCasedev) -> None:
        async with async_client.matters.v1.matter_parties.with_streaming_response.create(
            id="id",
            party_id="party_id",
            role="client",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            matter_party = await response.parse()
            assert matter_party is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_create(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.matters.v1.matter_parties.with_raw_response.create(
                id="",
                party_id="party_id",
                role="client",
            )

    @parametrize
    async def test_method_list(self, async_client: AsyncCasedev) -> None:
        matter_party = await async_client.matters.v1.matter_parties.list(
            "id",
        )
        assert matter_party is None

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncCasedev) -> None:
        response = await async_client.matters.v1.matter_parties.with_raw_response.list(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        matter_party = await response.parse()
        assert matter_party is None

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncCasedev) -> None:
        async with async_client.matters.v1.matter_parties.with_streaming_response.list(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            matter_party = await response.parse()
            assert matter_party is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_list(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.matters.v1.matter_parties.with_raw_response.list(
                "",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

from ..._types import SequenceNotStr

__all__ = ["MemoryCreateParams"]


class MemoryCreateParams(TypedDict, total=False):
    content: Required[str]

    type: Required[Literal["fact", "party", "issue", "deadline", "discovery", "correction", "preference"]]

    source: str

    tags: SequenceNotStr[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

from ..._types import SequenceNotStr

__all__ = ["MemoryUpdateParams"]


class MemoryUpdateParams(TypedDict, total=False):
    id: Required[str]

    content: str

    source: Optional[str]

    tags: SequenceNotStr[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Union
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from ...._types import SequenceNotStr
from ...._utils import PropertyInfo

__all__ = ["WorkItemCreateParams"]


class WorkItemCreateParams(TypedDict, total=False):
    title: Required[str]

    assignee_id: str

    description: str

    due_at: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]

    exit_criteria: SequenceNotStr[str]

    instructions: str

    metadata: Dict[str, object]

    priority: Literal["low", "normal", "high", "urgent"]

    type: Literal[
        "task", "deadline", "review", "filing", "communication", "research", "drafting", "collection", "intake"
    ]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional

import httpx

from ...._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.agent.v2 import execute_create_params
from ....types.agent.v2.execute_create_response import ExecuteCreateResponse

__all__ = ["ExecuteResource", "AsyncExecuteResource"]


class ExecuteResource(SyncAPIResource):
    """
    Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
    """

    @cached_property
    def with_raw_response(self) -> ExecuteResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return ExecuteResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ExecuteResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return ExecuteResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        prompt: str,
        agent_runtime: Optional[bool] | Omit = omit,
        disabled_tools: Optional[SequenceNotStr[str]] | Omit = omit,
        enabled_tools: Optional[SequenceNotStr[str]] | Omit = omit,
        guidance: Optional[str] | Omit = omit,
        instructions: str | Omit = omit,
        model: str | Omit = omit,
        object_ids: Optional[SequenceNotStr[str]] | Omit = omit,
        sandbox: Optional[execute_create_params.Sandbox] | Omit = omit,
        vault_ids: Optional[SequenceNotStr[str]] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ExecuteCreateResponse:
        """Creates an ephemeral agent and executes it immediately.

        By default this uses the
        lightweight synchronous linc runtime on Vercel Sandbox. Set `agentRuntime: true`
        to opt into the legacy Daytona-backed agent runtime.

        Args:
          agent_runtime: Set to true to opt into the legacy Daytona-backed agent runtime.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/agent/v2/execute",
            body=maybe_transform(
                {
                    "prompt": prompt,
                    "agent_runtime": agent_runtime,
                    "disabled_tools": disabled_tools,
                    "enabled_tools": enabled_tools,
                    "guidance": guidance,
                    "instructions": instructions,
                    "model": model,
                    "object_ids": object_ids,
                    "sandbox": sandbox,
                    "vault_ids": vault_ids,
                },
                execute_create_params.ExecuteCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ExecuteCreateResponse,
        )


class AsyncExecuteResource(AsyncAPIResource):
    """
    Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
    """

    @cached_property
    def with_raw_response(self) -> AsyncExecuteResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return AsyncExecuteResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncExecuteResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return AsyncExecuteResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        prompt: str,
        agent_runtime: Optional[bool] | Omit = omit,
        disabled_tools: Optional[SequenceNotStr[str]] | Omit = omit,
        enabled_tools: Optional[SequenceNotStr[str]] | Omit = omit,
        guidance: Optional[str] | Omit = omit,
        instructions: str | Omit = omit,
        model: str | Omit = omit,
        object_ids: Optional[SequenceNotStr[str]] | Omit = omit,
        sandbox: Optional[execute_create_params.Sandbox] | Omit = omit,
        vault_ids: Optional[SequenceNotStr[str]] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ExecuteCreateResponse:
        """Creates an ephemeral agent and executes it immediately.

        By default this uses the
        lightweight synchronous linc runtime on Vercel Sandbox. Set `agentRuntime: true`
        to opt into the legacy Daytona-backed agent runtime.

        Args:
          agent_runtime: Set to true to opt into the legacy Daytona-backed agent runtime.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/agent/v2/execute",
            body=await async_maybe_transform(
                {
                    "prompt": prompt,
                    "agent_runtime": agent_runtime,
                    "disabled_tools": disabled_tools,
                    "enabled_tools": enabled_tools,
                    "guidance": guidance,
                    "instructions": instructions,
                    "model": model,
                    "object_ids": object_ids,
                    "sandbox": sandbox,
                    "vault_ids": vault_ids,
                },
                execute_create_params.ExecuteCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ExecuteCreateResponse,
        )


class ExecuteResourceWithRawResponse:
    def __init__(self, execute: ExecuteResource) -> None:
        self._execute = execute

        self.create = to_raw_response_wrapper(
            execute.create,
        )


class AsyncExecuteResourceWithRawResponse:
    def __init__(self, execute: AsyncExecuteResource) -> None:
        self._execute = execute

        self.create = async_to_raw_response_wrapper(
            execute.create,
        )


class ExecuteResourceWithStreamingResponse:
    def __init__(self, execute: ExecuteResource) -> None:
        self._execute = execute

        self.create = to_streamed_response_wrapper(
            execute.create,
        )


class AsyncExecuteResourceWithStreamingResponse:
    def __init__(self, execute: AsyncExecuteResource) -> None:
        self._execute = execute

        self.create = async_to_streamed_response_wrapper(
            execute.create,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from casedev import Casedev, AsyncCasedev
from tests.utils import assert_matches_type
from casedev.types.llm.v1 import ChatCreateCompletionResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestChat:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create_completion(self, client: Casedev) -> None:
        chat = client.llm.v1.chat.create_completion(
            messages=[{}],
        )
        assert_matches_type(ChatCreateCompletionResponse, chat, path=["response"])

    @parametrize
    def test_method_create_completion_with_all_params(self, client: Casedev) -> None:
        chat = client.llm.v1.chat.create_completion(
            messages=[
                {
                    "content": "content",
                    "role": "system",
                }
            ],
            casemark_show_reasoning=False,
            frequency_penalty=0,
            max_tokens=1000,
            model="casemark/casemark-core-6",
            presence_penalty=0,
            stream=False,
            temperature=0.7,
            top_p=0,
        )
        assert_matches_type(ChatCreateCompletionResponse, chat, path=["response"])

    @parametrize
    def test_raw_response_create_completion(self, client: Casedev) -> None:
        response = client.llm.v1.chat.with_raw_response.create_completion(
            messages=[{}],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        chat = response.parse()
        assert_matches_type(ChatCreateCompletionResponse, chat, path=["response"])

    @parametrize
    def test_streaming_response_create_completion(self, client: Casedev) -> None:
        with client.llm.v1.chat.with_streaming_response.create_completion(
            messages=[{}],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            chat = response.parse()
            assert_matches_type(ChatCreateCompletionResponse, chat, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncChat:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_create_completion(self, async_client: AsyncCasedev) -> None:
        chat = await async_client.llm.v1.chat.create_completion(
            messages=[{}],
        )
        assert_matches_type(ChatCreateCompletionResponse, chat, path=["response"])

    @parametrize
    async def test_method_create_completion_with_all_params(self, async_client: AsyncCasedev) -> None:
        chat = await async_client.llm.v1.chat.create_completion(
            messages=[
                {
                    "content": "content",
                    "role": "system",
                }
            ],
            casemark_show_reasoning=False,
            frequency_penalty=0,
            max_tokens=1000,
            model="casemark/casemark-core-6",
            presence_penalty=0,
            stream=False,
            temperature=0.7,
            top_p=0,
        )
        assert_matches_type(ChatCreateCompletionResponse, chat, path=["response"])

    @parametrize
    async def test_raw_response_create_completion(self, async_client: AsyncCasedev) -> None:
        response = await async_client.llm.v1.chat.with_raw_response.create_completion(
            messages=[{}],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        chat = await response.parse()
        assert_matches_type(ChatCreateCompletionResponse, chat, path=["response"])

    @parametrize
    async def test_streaming_response_create_completion(self, async_client: AsyncCasedev) -> None:
        async with async_client.llm.v1.chat.with_streaming_response.create_completion(
            messages=[{}],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            chat = await response.parse()
            assert_matches_type(ChatCreateCompletionResponse, chat, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V1ListCourtsResponse", "Court"]


class Court(BaseModel):
    id: Optional[str] = None
    """Court slug (use as the court parameter in legal.docket())"""

    full_name: Optional[str] = FieldInfo(alias="fullName", default=None)

    jurisdiction: Optional[str] = None

    pacer_court_id: Optional[int] = FieldInfo(alias="pacerCourtId", default=None)

    short_name: Optional[str] = FieldInfo(alias="shortName", default=None)


class V1ListCourtsResponse(BaseModel):
    courts: Optional[List[Court]] = None

    found: Optional[int] = None

    in_use_only: Optional[bool] = FieldInfo(alias="inUseOnly", default=None)
    """Whether results are filtered to in-use courts only"""

    jurisdiction: Optional[str] = None

    query: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .log_list_params import LogListParams as LogListParams
from .type_list_params import TypeListParams as TypeListParams
from .log_create_params import LogCreateParams as LogCreateParams
from .log_export_params import LogExportParams as LogExportParams
from .party_list_params import PartyListParams as PartyListParams
from .type_create_params import TypeCreateParams as TypeCreateParams
from .type_update_params import TypeUpdateParams as TypeUpdateParams
from .log_export_response import LogExportResponse as LogExportResponse
from .party_create_params import PartyCreateParams as PartyCreateParams
from .share_create_params import ShareCreateParams as ShareCreateParams
from .work_item_list_params import WorkItemListParams as WorkItemListParams
from .agent_type_list_params import AgentTypeListParams as AgentTypeListParams
from .work_item_create_params import WorkItemCreateParams as WorkItemCreateParams
from .work_item_decide_params import WorkItemDecideParams as WorkItemDecideParams
from .work_item_update_params import WorkItemUpdateParams as WorkItemUpdateParams
from .agent_type_create_params import AgentTypeCreateParams as AgentTypeCreateParams
from .matter_party_create_params import MatterPartyCreateParams as MatterPartyCreateParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from casedev import Casedev, AsyncCasedev
from casedev._utils import parse_datetime

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestWorkItems:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: Casedev) -> None:
        work_item = client.matters.v1.work_items.create(
            id="id",
            title="title",
        )
        assert work_item is None

    @parametrize
    def test_method_create_with_all_params(self, client: Casedev) -> None:
        work_item = client.matters.v1.work_items.create(
            id="id",
            title="title",
            assignee_id="assignee_id",
            description="description",
            due_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            exit_criteria=["string"],
            instructions="instructions",
            metadata={"foo": "bar"},
            priority="low",
            type="task",
        )
        assert work_item is None

    @parametrize
    def test_raw_response_create(self, client: Casedev) -> None:
        response = client.matters.v1.work_items.with_raw_response.create(
            id="id",
            title="title",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        work_item = response.parse()
        assert work_item is None

    @parametrize
    def test_streaming_response_create(self, client: Casedev) -> None:
        with client.matters.v1.work_items.with_streaming_response.create(
            id="id",
            title="title",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            work_item = response.parse()
            assert work_item is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_create(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.matters.v1.work_items.with_raw_response.create(
                id="",
                title="title",
            )

    @parametrize
    def test_method_retrieve(self, client: Casedev) -> None:
        work_item = client.matters.v1.work_items.retrieve(
            work_item_id="workItemId",
            id="id",
        )
        assert work_item is None

    @parametrize
    def test_raw_response_retrieve(self, client: Casedev) -> None:
        response = client.matters.v1.work_items.with_raw_response.retrieve(
            work_item_id="workItemId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        work_item = response.parse()
        assert work_item is None

    @parametrize
    def test_streaming_response_retrieve(self, client: Casedev) -> None:
        with client.matters.v1.work_items.with_streaming_response.retrieve(
            work_item_id="workItemId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            work_item = response.parse()
            assert work_item is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.matters.v1.work_items.with_raw_response.retrieve(
                work_item_id="workItemId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `work_item_id` but received ''"):
            client.matters.v1.work_items.with_raw_response.retrieve(
                work_item_id="",
                id="id",
            )

    @parametrize
    def test_method_update(self, client: Casedev) -> None:
        work_item = client.matters.v1.work_items.update(
            work_item_id="workItemId",
            id="id",
        )
        assert work_item is None

    @parametrize
    def test_method_update_with_all_params(self, client: Casedev) -> None:
        work_item = client.matters.v1.work_items.update(
            work_item_id="workItemId",
            id="id",
            assignee_id="assignee_id",
            completed_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            description="description",
            due_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            exit_criteria=["string"],
            instructions="instructions",
            metadata={"foo": "bar"},
            priority="low",
            started_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            status="draft",
            title="title",
            type="task",
        )
        assert work_item is None

    @parametrize
    def test_raw_response_update(self, client: Casedev) -> None:
        response = client.matters.v1.work_items.with_raw_response.update(
            work_item_id="workItemId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        work_item = response.parse()
        assert work_item is None

    @parametrize
    def test_streaming_response_update(self, client: Casedev) -> None:
        with client.matters.v1.work_items.with_streaming_response.update(
            work_item_id="workItemId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            work_item = response.parse()
            assert work_item is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_update(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.matters.v1.work_items.with_raw_response.update(
                work_item_id="workItemId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `work_item_id` but received ''"):
            client.matters.v1.work_items.with_raw_response.update(
                work_item_id="",
                id="id",
            )

    @parametrize
    def test_method_list(self, client: Casedev) -> None:
        work_item = client.matters.v1.work_items.list(
            id="id",
        )
        assert work_item is None

    @parametrize
    def test_method_list_with_all_params(self, client: Casedev) -> None:
        work_item = client.matters.v1.work_items.list(
            id="id",
            assignee_id="assignee_id",
            status="status",
        )
        assert work_item is None

    @parametrize
    def test_raw_response_list(self, client: Casedev) -> None:
        response = client.matters.v1.work_items.with_raw_response.list(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        work_item = response.parse()
        assert work_item is None

    @parametrize
    def test_streaming_response_list(self, client: Casedev) -> None:
        with client.matters.v1.work_items.with_streaming_response.list(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            work_item = response.parse()
            assert work_item is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_list(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.matters.v1.work_items.with_raw_response.list(
                id="",
            )

    @parametrize
    def test_method_decide(self, client: Casedev) -> None:
        work_item = client.matters.v1.work_items.decide(
            work_item_id="workItemId",
            id="id",
            decision="approve",
        )
        assert work_item is None

    @parametrize
    def test_method_decide_with_all_params(self, client: Casedev) -> None:
        work_item = client.matters.v1.work_items.decide(
            work_item_id="workItemId",
            id="id",
            decision="approve",
            agent_type_id="agent_type_id",
            metadata={"foo": "bar"},
            reason="reason",
        )
        assert work_item is None

    @parametrize
    def test_raw_response_decide(self, client: Casedev) -> None:
        response = client.matters.v1.work_items.with_raw_response.decide(
            work_item_id="workItemId",
            id="id",
            decision="approve",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        work_item = response.parse()
        assert work_item is None

    @parametrize
    def test_streaming_response_decide(self, client: Casedev) -> None:
        with client.matters.v1.work_items.with_streaming_response.decide(
            work_item_id="workItemId",
            id="id",
            decision="approve",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            work_item = response.parse()
            assert work_item is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_decide(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.matters.v1.work_items.with_raw_response.decide(
                work_item_id="workItemId",
                id="",
                decision="approve",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `work_item_id` but received ''"):
            client.matters.v1.work_items.with_raw_response.decide(
                work_item_id="",
                id="id",
                decision="approve",
            )

    @parametrize
    def test_method_list_executions(self, client: Casedev) -> None:
        work_item = client.matters.v1.work_items.list_executions(
            work_item_id="workItemId",
            id="id",
        )
        assert work_item is None

    @parametrize
    def test_raw_response_list_executions(self, client: Casedev) -> None:
        response = client.matters.v1.work_items.with_raw_response.list_executions(
            work_item_id="workItemId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        work_item = response.parse()
        assert work_item is None

    @parametrize
    def test_streaming_response_list_executions(self, client: Casedev) -> None:
        with client.matters.v1.work_items.with_streaming_response.list_executions(
            work_item_id="workItemId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            work_item = response.parse()
            assert work_item is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_list_executions(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.matters.v1.work_items.with_raw_response.list_executions(
                work_item_id="workItemId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `work_item_id` but received ''"):
            client.matters.v1.work_items.with_raw_response.list_executions(
                work_item_id="",
                id="id",
            )


class TestAsyncWorkItems:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_create(self, async_client: AsyncCasedev) -> None:
        work_item = await async_client.matters.v1.work_items.create(
            id="id",
            title="title",
        )
        assert work_item is None

    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncCasedev) -> None:
        work_item = await async_client.matters.v1.work_items.create(
            id="id",
            title="title",
            assignee_id="assignee_id",
            description="description",
            due_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            exit_criteria=["string"],
            instructions="instructions",
            metadata={"foo": "bar"},
            priority="low",
            type="task",
        )
        assert work_item is None

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncCasedev) -> None:
        response = await async_client.matters.v1.work_items.with_raw_response.create(
            id="id",
            title="title",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        work_item = await response.parse()
        assert work_item is None

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncCasedev) -> None:
        async with async_client.matters.v1.work_items.with_streaming_response.create(
            id="id",
            title="title",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            work_item = await response.parse()
            assert work_item is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_create(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.matters.v1.work_items.with_raw_response.create(
                id="",
                title="title",
            )

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncCasedev) -> None:
        work_item = await async_client.matters.v1.work_items.retrieve(
            work_item_id="workItemId",
            id="id",
        )
        assert work_item is None

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncCasedev) -> None:
        response = await async_client.matters.v1.work_items.with_raw_response.retrieve(
            work_item_id="workItemId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        work_item = await response.parse()
        assert work_item is None

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncCasedev) -> None:
        async with async_client.matters.v1.work_items.with_streaming_response.retrieve(
            work_item_id="workItemId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            work_item = await response.parse()
            assert work_item is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.matters.v1.work_items.with_raw_response.retrieve(
                work_item_id="workItemId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `work_item_id` but received ''"):
            await async_client.matters.v1.work_items.with_raw_response.retrieve(
                work_item_id="",
                id="id",
            )

    @parametrize
    async def test_method_update(self, async_client: AsyncCasedev) -> None:
        work_item = await async_client.matters.v1.work_items.update(
            work_item_id="workItemId",
            id="id",
        )
        assert work_item is None

    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncCasedev) -> None:
        work_item = await async_client.matters.v1.work_items.update(
            work_item_id="workItemId",
            id="id",
            assignee_id="assignee_id",
            completed_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            description="description",
            due_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            exit_criteria=["string"],
            instructions="instructions",
            metadata={"foo": "bar"},
            priority="low",
            started_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            status="draft",
            title="title",
            type="task",
        )
        assert work_item is None

    @parametrize
    async def test_raw_response_update(self, async_client: AsyncCasedev) -> None:
        response = await async_client.matters.v1.work_items.with_raw_response.update(
            work_item_id="workItemId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        work_item = await response.parse()
        assert work_item is None

    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncCasedev) -> None:
        async with async_client.matters.v1.work_items.with_streaming_response.update(
            work_item_id="workItemId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            work_item = await response.parse()
            assert work_item is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_update(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.matters.v1.work_items.with_raw_response.update(
                work_item_id="workItemId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `work_item_id` but received ''"):
            await async_client.matters.v1.work_items.with_raw_response.update(
                work_item_id="",
                id="id",
            )

    @parametrize
    async def test_method_list(self, async_client: AsyncCasedev) -> None:
        work_item = await async_client.matters.v1.work_items.list(
            id="id",
        )
        assert work_item is None

    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncCasedev) -> None:
        work_item = await async_client.matters.v1.work_items.list(
            id="id",
            assignee_id="assignee_id",
            status="status",
        )
        assert work_item is None

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncCasedev) -> None:
        response = await async_client.matters.v1.work_items.with_raw_response.list(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        work_item = await response.parse()
        assert work_item is None

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncCasedev) -> None:
        async with async_client.matters.v1.work_items.with_streaming_response.list(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            work_item = await response.parse()
            assert work_item is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_list(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.matters.v1.work_items.with_raw_response.list(
                id="",
            )

    @parametrize
    async def test_method_decide(self, async_client: AsyncCasedev) -> None:
        work_item = await async_client.matters.v1.work_items.decide(
            work_item_id="workItemId",
            id="id",
            decision="approve",
        )
        assert work_item is None

    @parametrize
    async def test_method_decide_with_all_params(self, async_client: AsyncCasedev) -> None:
        work_item = await async_client.matters.v1.work_items.decide(
            work_item_id="workItemId",
            id="id",
            decision="approve",
            agent_type_id="agent_type_id",
            metadata={"foo": "bar"},
            reason="reason",
        )
        assert work_item is None

    @parametrize
    async def test_raw_response_decide(self, async_client: AsyncCasedev) -> None:
        response = await async_client.matters.v1.work_items.with_raw_response.decide(
            work_item_id="workItemId",
            id="id",
            decision="approve",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        work_item = await response.parse()
        assert work_item is None

    @parametrize
    async def test_streaming_response_decide(self, async_client: AsyncCasedev) -> None:
        async with async_client.matters.v1.work_items.with_streaming_response.decide(
            work_item_id="workItemId",
            id="id",
            decision="approve",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            work_item = await response.parse()
            assert work_item is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_decide(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.matters.v1.work_items.with_raw_response.decide(
                work_item_id="workItemId",
                id="",
                decision="approve",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `work_item_id` but received ''"):
            await async_client.matters.v1.work_items.with_raw_response.decide(
                work_item_id="",
                id="id",
                decision="approve",
            )

    @parametrize
    async def test_method_list_executions(self, async_client: AsyncCasedev) -> None:
        work_item = await async_client.matters.v1.work_items.list_executions(
            work_item_id="workItemId",
            id="id",
        )
        assert work_item is None

    @parametrize
    async def test_raw_response_list_executions(self, async_client: AsyncCasedev) -> None:
        response = await async_client.matters.v1.work_items.with_raw_response.list_executions(
            work_item_id="workItemId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        work_item = await response.parse()
        assert work_item is None

    @parametrize
    async def test_streaming_response_list_executions(self, async_client: AsyncCasedev) -> None:
        async with async_client.matters.v1.work_items.with_streaming_response.list_executions(
            work_item_id="workItemId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            work_item = await response.parse()
            assert work_item is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_list_executions(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.matters.v1.work_items.with_raw_response.list_executions(
                work_item_id="workItemId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `work_item_id` but received ''"):
            await async_client.matters.v1.work_items.with_raw_response.list_executions(
                work_item_id="",
                id="id",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["SkillResolveResponse", "Result"]


class Result(BaseModel):
    name: Optional[str] = None
    """Skill name"""

    score: Optional[float] = None
    """Relevance score"""

    slug: Optional[str] = None
    """Unique skill identifier"""

    source: Optional[Literal["curated", "custom"]] = None
    """Whether the skill is curated or org-custom"""

    summary: Optional[str] = None
    """Brief skill description"""

    tags: Optional[List[str]] = None
    """Skill tags"""


class SkillResolveResponse(BaseModel):
    methods_used: Optional[List[str]] = None
    """Search methods used (text, tag, semantic)"""

    results: Optional[List[Result]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["VaultListResponse", "Vault"]


class Vault(BaseModel):
    id: Optional[str] = None
    """Vault identifier"""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Vault creation timestamp"""

    description: Optional[str] = None
    """Vault description"""

    enable_graph: Optional[bool] = FieldInfo(alias="enableGraph", default=None)
    """Whether GraphRAG is enabled"""

    name: Optional[str] = None
    """Vault name"""

    total_bytes: Optional[int] = FieldInfo(alias="totalBytes", default=None)
    """Total storage size in bytes"""

    total_objects: Optional[int] = FieldInfo(alias="totalObjects", default=None)
    """Number of stored documents"""


class VaultListResponse(BaseModel):
    total: Optional[int] = None
    """Total number of vaults"""

    vaults: Optional[List[Vault]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["RunEventsParams"]


class RunEventsParams(TypedDict, total=False):
    last_event_id: Annotated[int, PropertyInfo(alias="lastEventId")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from casedev import Casedev, AsyncCasedev

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestSubscriptions:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: Casedev) -> None:
        subscription = client.vault.events.subscriptions.create(
            id="id",
            callback_url="https://example.com",
        )
        assert subscription is None

    @parametrize
    def test_method_create_with_all_params(self, client: Casedev) -> None:
        subscription = client.vault.events.subscriptions.create(
            id="id",
            callback_url="https://example.com",
            event_types=["string"],
            object_ids=["string"],
            signing_secret="signingSecret",
        )
        assert subscription is None

    @parametrize
    def test_raw_response_create(self, client: Casedev) -> None:
        response = client.vault.events.subscriptions.with_raw_response.create(
            id="id",
            callback_url="https://example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        subscription = response.parse()
        assert subscription is None

    @parametrize
    def test_streaming_response_create(self, client: Casedev) -> None:
        with client.vault.events.subscriptions.with_streaming_response.create(
            id="id",
            callback_url="https://example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            subscription = response.parse()
            assert subscription is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_create(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.events.subscriptions.with_raw_response.create(
                id="",
                callback_url="https://example.com",
            )

    @parametrize
    def test_method_update(self, client: Casedev) -> None:
        subscription = client.vault.events.subscriptions.update(
            subscription_id="subscriptionId",
            id="id",
        )
        assert subscription is None

    @parametrize
    def test_method_update_with_all_params(self, client: Casedev) -> None:
        subscription = client.vault.events.subscriptions.update(
            subscription_id="subscriptionId",
            id="id",
            callback_url="https://example.com",
            clear_signing_secret=True,
            event_types=["string"],
            is_active=True,
            object_ids=["string"],
            signing_secret="signingSecret",
        )
        assert subscription is None

    @parametrize
    def test_raw_response_update(self, client: Casedev) -> None:
        response = client.vault.events.subscriptions.with_raw_response.update(
            subscription_id="subscriptionId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        subscription = response.parse()
        assert subscription is None

    @parametrize
    def test_streaming_response_update(self, client: Casedev) -> None:
        with client.vault.events.subscriptions.with_streaming_response.update(
            subscription_id="subscriptionId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            subscription = response.parse()
            assert subscription is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_update(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.events.subscriptions.with_raw_response.update(
                subscription_id="subscriptionId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `subscription_id` but received ''"):
            client.vault.events.subscriptions.with_raw_response.update(
                subscription_id="",
                id="id",
            )

    @parametrize
    def test_method_list(self, client: Casedev) -> None:
        subscription = client.vault.events.subscriptions.list(
            "id",
        )
        assert subscription is None

    @parametrize
    def test_raw_response_list(self, client: Casedev) -> None:
        response = client.vault.events.subscriptions.with_raw_response.list(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        subscription = response.parse()
        assert subscription is None

    @parametrize
    def test_streaming_response_list(self, client: Casedev) -> None:
        with client.vault.events.subscriptions.with_streaming_response.list(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            subscription = response.parse()
            assert subscription is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_list(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.events.subscriptions.with_raw_response.list(
                "",
            )

    @parametrize
    def test_method_delete(self, client: Casedev) -> None:
        subscription = client.vault.events.subscriptions.delete(
            subscription_id="subscriptionId",
            id="id",
        )
        assert subscription is None

    @parametrize
    def test_raw_response_delete(self, client: Casedev) -> None:
        response = client.vault.events.subscriptions.with_raw_response.delete(
            subscription_id="subscriptionId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        subscription = response.parse()
        assert subscription is None

    @parametrize
    def test_streaming_response_delete(self, client: Casedev) -> None:
        with client.vault.events.subscriptions.with_streaming_response.delete(
            subscription_id="subscriptionId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            subscription = response.parse()
            assert subscription is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_delete(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.events.subscriptions.with_raw_response.delete(
                subscription_id="subscriptionId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `subscription_id` but received ''"):
            client.vault.events.subscriptions.with_raw_response.delete(
                subscription_id="",
                id="id",
            )

    @parametrize
    def test_method_test(self, client: Casedev) -> None:
        subscription = client.vault.events.subscriptions.test(
            subscription_id="subscriptionId",
            id="id",
        )
        assert subscription is None

    @parametrize
    def test_method_test_with_all_params(self, client: Casedev) -> None:
        subscription = client.vault.events.subscriptions.test(
            subscription_id="subscriptionId",
            id="id",
            event_type="eventType",
            object_id="objectId",
            payload={"foo": "bar"},
        )
        assert subscription is None

    @parametrize
    def test_raw_response_test(self, client: Casedev) -> None:
        response = client.vault.events.subscriptions.with_raw_response.test(
            subscription_id="subscriptionId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        subscription = response.parse()
        assert subscription is None

    @parametrize
    def test_streaming_response_test(self, client: Casedev) -> None:
        with client.vault.events.subscriptions.with_streaming_response.test(
            subscription_id="subscriptionId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            subscription = response.parse()
            assert subscription is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_test(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.events.subscriptions.with_raw_response.test(
                subscription_id="subscriptionId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `subscription_id` but received ''"):
            client.vault.events.subscriptions.with_raw_response.test(
                subscription_id="",
                id="id",
            )


class TestAsyncSubscriptions:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_create(self, async_client: AsyncCasedev) -> None:
        subscription = await async_client.vault.events.subscriptions.create(
            id="id",
            callback_url="https://example.com",
        )
        assert subscription is None

    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncCasedev) -> None:
        subscription = await async_client.vault.events.subscriptions.create(
            id="id",
            callback_url="https://example.com",
            event_types=["string"],
            object_ids=["string"],
            signing_secret="signingSecret",
        )
        assert subscription is None

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.events.subscriptions.with_raw_response.create(
            id="id",
            callback_url="https://example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        subscription = await response.parse()
        assert subscription is None

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.events.subscriptions.with_streaming_response.create(
            id="id",
            callback_url="https://example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            subscription = await response.parse()
            assert subscription is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_create(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.events.subscriptions.with_raw_response.create(
                id="",
                callback_url="https://example.com",
            )

    @parametrize
    async def test_method_update(self, async_client: AsyncCasedev) -> None:
        subscription = await async_client.vault.events.subscriptions.update(
            subscription_id="subscriptionId",
            id="id",
        )
        assert subscription is None

    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncCasedev) -> None:
        subscription = await async_client.vault.events.subscriptions.update(
            subscription_id="subscriptionId",
            id="id",
            callback_url="https://example.com",
            clear_signing_secret=True,
            event_types=["string"],
            is_active=True,
            object_ids=["string"],
            signing_secret="signingSecret",
        )
        assert subscription is None

    @parametrize
    async def test_raw_response_update(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.events.subscriptions.with_raw_response.update(
            subscription_id="subscriptionId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        subscription = await response.parse()
        assert subscription is None

    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.events.subscriptions.with_streaming_response.update(
            subscription_id="subscriptionId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            subscription = await response.parse()
            assert subscription is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_update(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.events.subscriptions.with_raw_response.update(
                subscription_id="subscriptionId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `subscription_id` but received ''"):
            await async_client.vault.events.subscriptions.with_raw_response.update(
                subscription_id="",
                id="id",
            )

    @parametrize
    async def test_method_list(self, async_client: AsyncCasedev) -> None:
        subscription = await async_client.vault.events.subscriptions.list(
            "id",
        )
        assert subscription is None

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.events.subscriptions.with_raw_response.list(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        subscription = await response.parse()
        assert subscription is None

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.events.subscriptions.with_streaming_response.list(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            subscription = await response.parse()
            assert subscription is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_list(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.events.subscriptions.with_raw_response.list(
                "",
            )

    @parametrize
    async def test_method_delete(self, async_client: AsyncCasedev) -> None:
        subscription = await async_client.vault.events.subscriptions.delete(
            subscription_id="subscriptionId",
            id="id",
        )
        assert subscription is None

    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.events.subscriptions.with_raw_response.delete(
            subscription_id="subscriptionId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        subscription = await response.parse()
        assert subscription is None

    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.events.subscriptions.with_streaming_response.delete(
            subscription_id="subscriptionId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            subscription = await response.parse()
            assert subscription is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_delete(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.events.subscriptions.with_raw_response.delete(
                subscription_id="subscriptionId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `subscription_id` but received ''"):
            await async_client.vault.events.subscriptions.with_raw_response.delete(
                subscription_id="",
                id="id",
            )

    @parametrize
    async def test_method_test(self, async_client: AsyncCasedev) -> None:
        subscription = await async_client.vault.events.subscriptions.test(
            subscription_id="subscriptionId",
            id="id",
        )
        assert subscription is None

    @parametrize
    async def test_method_test_with_all_params(self, async_client: AsyncCasedev) -> None:
        subscription = await async_client.vault.events.subscriptions.test(
            subscription_id="subscriptionId",
            id="id",
            event_type="eventType",
            object_id="objectId",
            payload={"foo": "bar"},
        )
        assert subscription is None

    @parametrize
    async def test_raw_response_test(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.events.subscriptions.with_raw_response.test(
            subscription_id="subscriptionId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        subscription = await response.parse()
        assert subscription is None

    @parametrize
    async def test_streaming_response_test(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.events.subscriptions.with_streaming_response.test(
            subscription_id="subscriptionId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            subscription = await response.parse()
            assert subscription is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_test(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.events.subscriptions.with_raw_response.test(
                subscription_id="subscriptionId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `subscription_id` but received ''"):
            await async_client.vault.events.subscriptions.with_raw_response.test(
                subscription_id="",
                id="id",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["V1GetFullTextParams"]


class V1GetFullTextParams(TypedDict, total=False):
    url: Required[str]
    """URL of the verified legal document"""

    highlight_query: Annotated[str, PropertyInfo(alias="highlightQuery")]
    """Optional query to extract relevant highlights (e.g., "What is the holding?")"""

    max_characters: Annotated[int, PropertyInfo(alias="maxCharacters")]
    """Maximum characters to return (default: 10000, max: 50000)"""

    summary_query: Annotated[str, PropertyInfo(alias="summaryQuery")]
    """Optional query for generating a summary (e.g., "Summarize the key ruling")"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Mapping, Iterable, cast
from typing_extensions import Literal

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import extract_files, maybe_transform, deepcopy_minimal, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    BinaryAPIResponse,
    AsyncBinaryAPIResponse,
    StreamedBinaryAPIResponse,
    AsyncStreamedBinaryAPIResponse,
    to_custom_raw_response_wrapper,
    to_custom_streamed_response_wrapper,
    async_to_custom_raw_response_wrapper,
    async_to_custom_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.superdoc import v1_convert_params, v1_annotate_params

__all__ = ["V1Resource", "AsyncV1Resource"]


class V1Resource(SyncAPIResource):
    """Document conversion and template automation"""

    @cached_property
    def with_raw_response(self) -> V1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return V1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> V1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return V1ResourceWithStreamingResponse(self)

    def annotate(
        self,
        *,
        document: v1_annotate_params.Document,
        fields: Iterable[v1_annotate_params.Field],
        output_format: Literal["docx", "pdf"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BinaryAPIResponse:
        """Populate fields inside a DOCX template using SuperDoc annotations.

        Supports
        text, images, dates, and numbers. Can target individual fields by ID or multiple
        fields by group.

        Args:
          document: Document source - provide either URL or base64

          fields: Fields to populate in the template

          output_format: Output format for the annotated document

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "application/pdf", **(extra_headers or {})}
        return self._post(
            "/superdoc/v1/annotate",
            body=maybe_transform(
                {
                    "document": document,
                    "fields": fields,
                    "output_format": output_format,
                },
                v1_annotate_params.V1AnnotateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BinaryAPIResponse,
        )

    def convert(
        self,
        *,
        from_: Literal["docx", "md", "html"],
        document_base64: str | Omit = omit,
        document_url: str | Omit = omit,
        to: Literal["pdf", "docx"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BinaryAPIResponse:
        """Convert documents between formats using SuperDoc.

        Supports DOCX to PDF, Markdown
        to DOCX, and HTML to DOCX conversions.

        Args:
          from_: Source format of the document

          document_base64: Base64-encoded document content

          document_url: URL to the document to convert

          to: Target format for conversion

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "application/pdf", **(extra_headers or {})}
        body = deepcopy_minimal(
            {
                "from_": from_,
                "document_base64": document_base64,
                "document_url": document_url,
                "to": to,
            }
        )
        files = extract_files(cast(Mapping[str, object], body), paths=[["file"]])
        if files:
            # It should be noted that the actual Content-Type header that will be
            # sent to the server will contain a `boundary` parameter, e.g.
            # multipart/form-data; boundary=---abc--
            extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return self._post(
            "/superdoc/v1/convert",
            body=maybe_transform(body, v1_convert_params.V1ConvertParams),
            files=files,
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BinaryAPIResponse,
        )


class AsyncV1Resource(AsyncAPIResource):
    """Document conversion and template automation"""

    @cached_property
    def with_raw_response(self) -> AsyncV1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return AsyncV1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncV1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return AsyncV1ResourceWithStreamingResponse(self)

    async def annotate(
        self,
        *,
        document: v1_annotate_params.Document,
        fields: Iterable[v1_annotate_params.Field],
        output_format: Literal["docx", "pdf"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncBinaryAPIResponse:
        """Populate fields inside a DOCX template using SuperDoc annotations.

        Supports
        text, images, dates, and numbers. Can target individual fields by ID or multiple
        fields by group.

        Args:
          document: Document source - provide either URL or base64

          fields: Fields to populate in the template

          output_format: Output format for the annotated document

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "application/pdf", **(extra_headers or {})}
        return await self._post(
            "/superdoc/v1/annotate",
            body=await async_maybe_transform(
                {
                    "document": document,
                    "fields": fields,
                    "output_format": output_format,
                },
                v1_annotate_params.V1AnnotateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AsyncBinaryAPIResponse,
        )

    async def convert(
        self,
        *,
        from_: Literal["docx", "md", "html"],
        document_base64: str | Omit = omit,
        document_url: str | Omit = omit,
        to: Literal["pdf", "docx"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncBinaryAPIResponse:
        """Convert documents between formats using SuperDoc.

        Supports DOCX to PDF, Markdown
        to DOCX, and HTML to DOCX conversions.

        Args:
          from_: Source format of the document

          document_base64: Base64-encoded document content

          document_url: URL to the document to convert

          to: Target format for conversion

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "application/pdf", **(extra_headers or {})}
        body = deepcopy_minimal(
            {
                "from_": from_,
                "document_base64": document_base64,
                "document_url": document_url,
                "to": to,
            }
        )
        files = extract_files(cast(Mapping[str, object], body), paths=[["file"]])
        if files:
            # It should be noted that the actual Content-Type header that will be
            # sent to the server will contain a `boundary` parameter, e.g.
            # multipart/form-data; boundary=---abc--
            extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return await self._post(
            "/superdoc/v1/convert",
            body=await async_maybe_transform(body, v1_convert_params.V1ConvertParams),
            files=files,
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AsyncBinaryAPIResponse,
        )


class V1ResourceWithRawResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

        self.annotate = to_custom_raw_response_wrapper(
            v1.annotate,
            BinaryAPIResponse,
        )
        self.convert = to_custom_raw_response_wrapper(
            v1.convert,
            BinaryAPIResponse,
        )


class AsyncV1ResourceWithRawResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

        self.annotate = async_to_custom_raw_response_wrapper(
            v1.annotate,
            AsyncBinaryAPIResponse,
        )
        self.convert = async_to_custom_raw_response_wrapper(
            v1.convert,
            AsyncBinaryAPIResponse,
        )


class V1ResourceWithStreamingResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

        self.annotate = to_custom_streamed_response_wrapper(
            v1.annotate,
            StreamedBinaryAPIResponse,
        )
        self.convert = to_custom_streamed_response_wrapper(
            v1.convert,
            StreamedBinaryAPIResponse,
        )


class AsyncV1ResourceWithStreamingResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

        self.annotate = async_to_custom_streamed_response_wrapper(
            v1.annotate,
            AsyncStreamedBinaryAPIResponse,
        )
        self.convert = async_to_custom_streamed_response_wrapper(
            v1.convert,
            AsyncStreamedBinaryAPIResponse,
        )
